FunctionType

Enum FunctionType 

pub enum FunctionType {
    Function(Handle<Function>),
    EntryPoint(EntryPointIndex),
}
Whether we’re generating an entry point or a regular function.

Backend languages often require different code for a Function depending on whether it represents an EntryPoint or not. Backends can pass common code one of these values to select the right behavior.

These values also carry enough information to find the Function in the Module: the Handle for a regular function, or the index into Module::entry_points for an entry point.

Variants



Function(Handle<Function>)

A regular function.



EntryPoint(EntryPointIndex)

An EntryPoint, and its index in Module::entry_points.

Implementations

Source

impl FunctionType

pub fn is_compute_like_entry_point(&self, module: &Module) -> bool

Returns true if the function is an entry point for a compute-like shader.