Enum Version
pub enum Version {
Desktop(u16),
Embedded {
version: u16,
is_webgl: bool,
},
}Expand description
A GLSL version.
Variants
Implementations
impl Version
impl Version
pub fn is_supported(&self) -> bool
pub fn is_supported(&self) -> bool
Checks the list of currently supported versions and returns true if it contains the specified version
Notes
As an invalid version number will never be added to the supported version list so this also checks for version validity
pub fn supports_io_locations(&self) -> bool
pub fn supports_explicit_locations(&self) -> bool
pub fn supports_explicit_locations(&self) -> bool
Checks if the version supports all of the explicit layouts:
location=qualifiers for bindingsbinding=qualifiers for resources
Note: location= for vertex inputs and fragment outputs is supported
unconditionally for GLES 300.
pub fn supports_early_depth_test(&self) -> bool
pub fn supports_std140_layout(&self) -> bool
pub fn supports_std430_layout(&self) -> bool
pub fn supports_fma_function(&self) -> bool
pub fn supports_integer_functions(&self) -> bool
pub fn supports_frexp_function(&self) -> bool
pub fn supports_derivative_control(&self) -> bool
pub fn supports_pack_unpack_4x8(&self) -> bool
pub fn supports_pack_unpack_snorm_2x16(&self) -> bool
pub fn supports_pack_unpack_unorm_2x16(&self) -> bool
pub fn supports_pack_unpack_half_2x16(&self) -> bool