fn get_inner_matrix_of_global_uniform(
module: &Module,
base: Handle<Expression>,
func_ctx: &FunctionCtx<'_>,
direct: bool,
) -> Option<MatrixType>Expand description
Returns the matrix data if the access chain starting at base:
- starts with an expression with resolved type of
TypeInner::Matrix, or - contains zero or more expressions with resolved type of
TypeInner::ArrayofTypeInner::Matrixifdirect = false - and ends with an
Expression::GlobalVariableinAddressSpace::Uniform