pub(super) struct EntryPointBinding {
pub(super) arg_name: String,
pub(super) ty_name: String,
pub(super) members: Vec<EpStructMember>,
pub(super) local_invocation_index_name: Option<String>,
}Expand description
Structure contains information required for generating wrapped structure of all entry points arguments
Fields
arg_name: StringName of the fake EP argument that contains the struct with all the flattened input data.
ty_name: StringGenerated structure name
members: Vec<EpStructMember>Members of generated structure
local_invocation_index_name: Option<String>Auto Trait Implementations
impl Freeze for EntryPointBinding
impl RefUnwindSafe for EntryPointBinding
impl Send for EntryPointBinding
impl Sync for EntryPointBinding
impl Unpin for EntryPointBinding
impl UnwindSafe for EntryPointBinding