pub(super) struct EntryPointInterface {
pub(crate) input: Option<EntryPointBinding>,
pub(crate) output: Option<EntryPointBinding>,
pub(crate) mesh_vertices: Option<EntryPointBinding>,
pub(crate) mesh_primitives: Option<EntryPointBinding>,
pub(crate) mesh_indices: Option<EntryPointBinding>,
}Fields
input: Option<EntryPointBinding>If Some, the input of an entry point is gathered in a special
struct with members sorted by binding.
The EntryPointBinding::members array is sorted by index,
so that we can walk it in write_ep_arguments_initialization.
output: Option<EntryPointBinding>If Some, the output of an entry point is flattened.
The EntryPointBinding::members array is sorted by binding,
So that we can walk it in Statement::Return handler.
mesh_vertices: Option<EntryPointBinding>mesh_primitives: Option<EntryPointBinding>mesh_indices: Option<EntryPointBinding>Auto Trait Implementations
impl Freeze for EntryPointInterface
impl RefUnwindSafe for EntryPointInterface
impl Send for EntryPointInterface
impl Sync for EntryPointInterface
impl Unpin for EntryPointInterface
impl UnwindSafe for EntryPointInterface