debug_str_bytes_to_words

Function debug_str_bytes_to_words 

pub(super) fn debug_str_bytes_to_words(bytes: &[u8]) -> Vec<Word> 
Convert bytes to a vector of SPIR-V words, replacing NUL bytes with ?.

(Using the replacement character or NUL symbol would require changing the length of the string, which would complicate chunking of the program source.)