pub struct MeshReturnInfo {
out_variable_id: Word,
out_members: Vec<MeshReturnMember>,
local_invocation_index_var_id: Word,
workgroup_size: u32,
vertex_info: PerOutputTypeMeshReturnInfo,
primitive_info: PerOutputTypeMeshReturnInfo,
primitive_indices: Option<Word>,
}Fields
out_variable_id: WordId of the workgroup variable containing the data to be output
out_members: Vec<MeshReturnMember>All members of the output variable struct type
local_invocation_index_var_id: WordId of the input variable for local invocation id
workgroup_size: u32Total workgroup size (product)
vertex_info: PerOutputTypeMeshReturnInfoVertex-specific info
primitive_info: PerOutputTypeMeshReturnInfoPrimitive-specific info
primitive_indices: Option<Word>Array variable for the primitive indices builtin