pub struct ParseErrors {
pub errors: Vec<Error>,
}Expand description
A collection of errors returned during shader parsing.
Fields
errors: Vec<Error>Implementations
Sourceimpl ParseErrors
impl ParseErrors
pub fn emit_to_writer(&self, writer: &mut impl ErrorWrite, source: &str)
pub fn emit_to_writer_with_path( &self, writer: &mut impl ErrorWrite, source: &str, path: &str, )
Sourcepub fn emit_to_stderr(&self, source: &str)
pub fn emit_to_stderr(&self, source: &str)
Emits a summary of the errors to standard error stream.
Sourcepub fn emit_to_stderr_with_path(&self, source: &str, path: &str)
pub fn emit_to_stderr_with_path(&self, source: &str, path: &str)
Emits a summary of the errors to standard error stream.
pub fn emit_to_string(&self, source: &str) -> String
pub fn emit_to_string_with_path(&self, source: &str, path: &str) -> String
fn make_diagnostic(err: &Error) -> Diagnostic<()>