pub struct CallPhrase<'a> {
pub function: TemplateElaboratedIdent<'a>,
pub arguments: Vec<Handle<Expression<'a>>>,
}Expand description
A function call or value constructor expression.
We can’t tell whether an expression like IDENTIFIER(EXPR, ...) is a
construction expression or a function call until we know IDENTIFIER’s
definition, so we represent everything of that form as one of these
expressions until lowering. At that point, Lowerer::call has
everything’s definition in hand, and can decide whether to emit a Naga
Constant, As, Splat, or Compose expression.
Fields
function: TemplateElaboratedIdent<'a>arguments: Vec<Handle<Expression<'a>>>Trait Implementations