fn component_wise_signed<const N: usize, const M: usize>(
eval: &mut ConstantEvaluator<'_>,
span: Span,
exprs: [Handle<Expression>; N],
handler: fn(Signed<N>) -> Result<Signed<M>, ConstantEvaluatorError>,
) -> Result<Handle<Expression>, ConstantEvaluatorError>Expand description
Attempts to evaluate multiple exprs as a combined Signed to pass to handler.
If exprs are vectors of the same length, handler is called for each corresponding
component of each vector.
handler’s output is registered as a new expression. If exprs are vectors of the
same length, a new vector expression is registered, composed of each component emitted
by handler.