enum TraceRayVertexReturnState {
NoTraceRays,
NoVertexReturn(Span),
VertexReturn,
}Variants
NoTraceRays
No trace ray calls yet have been found.
NoVertexReturn(Span)
Trace ray calls have been found, at least one uses an acceleration structure that does not have the flag enabling vertex return.
VertexReturn
Trace ray calls have been found, all acceleration structures have the flag enabling vertex return.