pub struct ImmediateSlots(u64);Expand description
A bitmask, tracking which 4-byte slots have been written via set_immediates.
Bit N corresponds to bytes [N4 .. N4+4).
Tuple Fields
0: u64Implementations
Sourceimpl ImmediateSlots
impl ImmediateSlots
pub const fn from_raw(raw: u64) -> Self
Sourcepub const fn from_range(
offset: u32,
size_bytes: u32,
) -> Result<Self, ImmediateSlotsOverflowError>
pub const fn from_range( offset: u32, size_bytes: u32, ) -> Result<Self, ImmediateSlotsOverflowError>
Compute the bitmask for a byte range [offset .. offset + size_bytes).
Sourcepub fn from_type(
ty: &TypeInner,
types: &UniqueArena<Type>,
gctx: GlobalCtx<'_>,
) -> Result<Self, ImmediateSlotsOverflowError>
pub fn from_type( ty: &TypeInner, types: &UniqueArena<Type>, gctx: GlobalCtx<'_>, ) -> Result<Self, ImmediateSlotsOverflowError>
Compute the slots occupied by a type, excluding padding between matrix columns or struct members.
Sourcepub const fn contains(self, other: Self) -> bool
pub const fn contains(self, other: Self) -> bool
Returns true if self contains all bits in other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
Returns the bits in self that are not set in other.