fn element_or_member_type(
ty: Handle<Type>,
i: usize,
types: &mut UniqueArena<Type>,
) -> Handle<Type>Expand description
Helper method used to retrieve the child type of ty at
index i.
Note
Does not check if the index is valid and returns the same type when indexing out-of-bounds a struct or indexing a non indexable type.