pub enum RayPipelineFunction {
TraceRay {
acceleration_structure: Handle<Expression>,
descriptor: Handle<Expression>,
payload: Handle<Expression>,
},
}Expand description
Ray tracing pipeline intrinsics
Variants
TraceRay
Traces a ray through the given acceleration structure
Fields

acceleration_structure: Handle<Expression>The acceleration structure within which this ray should search for hits.
The expression must be an AccelerationStructure.

descriptor: Handle<Expression>A struct of detailed parameters for the ray query.
This expression should have the struct type given in
SpecialTypes::ray_desc. This is available in the WGSL
front end as the RayDesc type.

payload: Handle<Expression>A pointer in the ray_payload or incoming_ray_payload address spaces