ImmediateSlots

Struct ImmediateSlots 

pub struct ImmediateSlots(u64);
A bitmask, tracking which 4-byte slots have been written via set_immediates. Bit N corresponds to bytes [N4 .. N4+4).

Tuple Fields

0: u64

Implementations

Source

impl ImmediateSlots

pub const fn from_raw(raw: u64) -> Self

pub const fn from_range(offset: u32, size_bytes: u32) -> Self

Compute the bitmask for a byte range [offset .. offset + size_bytes).

pub fn from_type( ty: &TypeInner, offset: u32, types: &UniqueArena<Type>, gctx: GlobalCtx<'_>, ) -> Self

Compute the slots occupied by a type at a given byte offset, excluding padding between struct members.

pub const fn contains(self, other: Self) -> bool

Returns true if self contains all bits in other.

pub const fn difference(self, other: Self) -> Self

Returns the bits in self that are not set in other.

pub fn size_for_module(module: &Module) -> u32

Returns the byte size of the var<immediate> type in a module. Zero if the module has no var<immediate>.

pub(crate) fn for_pointer( pointer: Handle<Expression>, global: Handle<GlobalVariable>, expression_arena: &Arena<Expression>, global_vars: &Arena<GlobalVariable>, types: &UniqueArena<Type>, ) -> Self

Compute the immediate slot bitmask for a pointer expression that refers to (part of) an immediate global variable.

global is the handle of the immediate global variable that this pointer derives from (obtained from assignable_global).